# Automatic 2D class selection

Simple binary classification tool to select good / bad classes based on pretrained deep learning network.

More information: http://sphire.mpg.de/wiki/doku.php?id=auto_2d_class_selection
